==> MoinLight-0.1.tar.bz2: MoinLight-0.1/moinformat/macros/attachlist.py <==
#!/usr/bin/env python

"""
AttachList macro for Moin compatibility.

Copyright (C) 2019 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from mimetypes import guess_type
from moinformat.macros.common import Macro
from moinformat.tree.moin import Link, LinkLabel, List, ListItem, Text
from moinformat.utils.links import LinkTarget

class AttachListMacro(Macro):

    "An attachment list macro."

    name = "AttachList"

    def evaluate(self):

        "Evaluate the macro, producing a list of attachments."

        # Obtain the parameters.

        args = self.node.args

        pagename = args and args[0] or self.metadata.get("pagename")
        mimetype = len(args) > 1 and args[1] or None

        # Access the input context to get the attachment details.

        input = self.metadata.get_input()

        # Select attachments by type.

        all_filenames = pagename and input.get_attachments(pagename) or []

        if mimetype:
            filenames = []

            for filename in all_filenames:
                type, encoding = guess_type(filename)

                if type == mimetype:
                    filenames.append(filename)
        else:
            filenames = all_filenames

        # Sort the filenames.
        # NOTE: The actual sort order should be controlled.

        filenames.sort()

        # Prepare a list of links.

        items = []
        indent = 0
        marker = "*"
        space = " "
        num = None

        for filename in filenames:
            text = [Text(filename)]
            nodes = [Link([LinkLabel(text)], LinkTarget("attachment", filename))]
            items.append(ListItem(nodes, indent, marker, space, num))

        # Replace the macro node with the list.

        macro = self.node
        macro.parent.replace(macro, List(items))

macro = AttachListMacro

# vim: tabstop=4 expandtab shiftwidth=4

==> MoinLight-0.2.1.tar.bz2: MoinLight-0.2.1/moinformat/macros/attachlist.py <==
#!/usr/bin/env python

"""
AttachList macro for Moin compatibility.

Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from mimetypes import guess_type
from moinformat.macros.common import Macro
from moinformat.tree.moin import Link, LinkLabel, List, ListItem, Text
from moinformat.utils.links import LinkTarget

class AttachListMacro(Macro):

    "An attachment list macro."

    name = "AttachList"

    def evaluate(self):

        "Evaluate the macro, producing a list of attachments."

        # Obtain the parameters.

        args = self.node.args

        pagename = args and args[0] or self.metadata.get("pagename")
        mimetype = len(args) > 1 and args[1] or None

        # Access the input context to get the attachment details.

        input = self.metadata.get_input()

        # Select attachments by type.

        all_filenames = pagename and input.get_attachments(pagename) or []

        if mimetype:
            filenames = []

            for filename in all_filenames:
                type, encoding = guess_type(filename)

                if type == mimetype:
                    filenames.append(filename)
        else:
            filenames = all_filenames

        # Sort the filenames.
        # NOTE: The actual sort order should be controlled.

        filenames.sort()

        # Prepare a list of links.

        items = []
        indent = 0
        marker = "*"
        space = " "
        num = None

        for filename in filenames:
            text = [Text(filename)]
            nodes = [Link([LinkLabel(text)], LinkTarget("attachment", filename,
                                                        pagename=pagename))]
            items.append(ListItem(nodes, indent, marker, space, num))

        # Replace the macro node with the list.

        macro = self.node
        macro.parent.replace(macro, List(items))

macro = AttachListMacro

# vim: tabstop=4 expandtab shiftwidth=4
